@@ -2,15 +2,14 @@ import json
 import os
 
 
-root_dir = os.path.dirname(os.path.realpath(__file__))
+root_dir = os.path.expanduser(os.path.join('~', '.wavecount_cli'))
 filename = os.path.expanduser(root_dir + '/config.json')
-base_url = 'https://wavecountbackendapifunctionapp.azurewebsites.net/api'
 
 
 def read_config():
     cfg = {}
     if not os.path.exists(filename):
-        cfg['base_url'] = base_url
+        os.makedirs(root_dir, exist_ok=True)
         with open(filename, 'w+') as cfg_file:
             json.dump(cfg, cfg_file, indent=4)
     else:
